<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Српски [SR]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=458
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Српски';
$lang_info['country'] = 'Србија';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'sr';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d категорија обновљена';
$lang['%d albums updated'] = '%d категорије обновљене';
$lang['%d comment to validate'] = '%d коментар за оверу';
$lang['%d comments to validate'] = '%d коментари за оверу';
$lang['%d new comment'] = '%d нови коментар';
$lang['%d new comments'] = '%d нови коментари';
$lang['%d comment'] = '%d коментар';
$lang['%d comments'] = '%d коментари';
$lang['%d hit'] = '%d посета';
$lang['%d hits'] = '%d посета';
$lang['%d new photo'] = 'број нових слика: %d';
$lang['%d new photos'] = 'нове слике - %d';
$lang['%d new user'] = '%d нови корисник';
$lang['%d new users'] = '%d нови корисници';
$lang['About'] = 'O...';
$lang['All tags'] = 'Све ознаке';
$lang['Any tag'] = 'Било која ознака';
$lang['At least one listed rule must be satisfied.'] = 'Најмање једно од наведених правила мора бити задовољено.';
$lang['At least one tag must match'] = 'Најмање једна ознака се мора поклапати';
$lang['Author'] = 'Аутор';
$lang['Albums'] = 'Категорије';
$lang['Album'] = 'Категорија';
$lang['Close this window'] = 'Затвори прозор';
$lang['Complete RSS feed (photos, comments)'] = 'Потпуни RSS извори (слике, коментари)';
$lang['Confirm Password'] = 'Потврди Лозинку';
$lang['Connection settings'] = 'Подешавања повезивања';
$lang['Login'] = 'Пријава';
$lang['Contact webmaster'] = 'Пишите wебмастер-у';
$lang['Create a new account'] = 'Направи нови налог';
$lang['Created on'] = 'Датум израде:';
$lang['Creation date'] = 'Датум израде';
$lang['Current password is wrong'] = 'Тренутна лозинка је неисправна';
$lang['Dimensions'] = 'Величине';
$lang['Display'] = 'Приказ';
$lang['Each listed rule must be satisfied.'] = 'Свако наведено правило мора бити задовољено.';
$lang['Email address is missing. Please specify an email address.'] = 'Недостаје адреса електронске поште';
$lang['Email address'] = 'Адреса електронске поште';
$lang['Enter your personnal informations'] = 'Упишите своје личне податке';
$lang['Error sending email'] = 'Грешка приликом слања електронске поште';
$lang['File name'] = 'Назив датотеке';
$lang['File'] = 'Датотека';
$lang['Filesize'] = 'Величина датотеке';
$lang['Filter and display'] = 'Филтер и приказ';
$lang['Filter'] = 'Филтер';
$lang['Forgot your password?'] = 'Заборавили сте лозинку?';
$lang['Go through the gallery as a visitor'] = 'Прегледајте галерију као посетиоц';
$lang['Help'] = 'Помоћ';
$lang['Identification'] = 'Пријава';
$lang['Photos only RSS feed'] = 'RSS извор само за слике';
$lang['Keyword'] = 'Кључна реч';
$lang['Links'] = 'Интернет везе';
$lang['N/A'] = 'Н/Д';
$lang['New on %s'] = 'Нови на %s';
$lang['New password confirmation does not correspond'] = 'Потврда нове лозинке не одговара';
$lang['Notification'] = 'Обавештење';
$lang['Number of items'] = 'Број ставки';
$lang['Original dimensions'] = 'Изворне величине';
$lang['Password forgotten'] = 'Заборављена лозинка';
$lang['Password'] = 'Лозинка';
$lang['Post date'] = 'Датум објаве:';
$lang['Posted on'] = 'Датум објављивања';
$lang['Profile'] = 'Профил';
$lang['Quick connect'] = 'Брза веза';
$lang['RSS feed'] = 'RSS извор';
$lang['Register'] = 'Упишите се';
$lang['Registration'] = 'Регистрација';
$lang['Related tags'] = 'Повезане ознаке';
$lang['Reset'] = 'Поништи';
$lang['Retrieve password'] = 'Врати лозинку';
$lang['Search rules'] = 'Правила претраге';
$lang['Search tags'] = 'Ознаке претраге';
$lang['Search'] = 'Претраживање';
$lang['display available tags'] = 'Погледај доступне ознаке';
$lang['Since'] = 'Од';
$lang['Sort by'] = 'Сложено по';
$lang['Sort order'] = 'Редослед слагања';
$lang['Tag'] = 'Ознака';
$lang['Tags'] = 'Ознаке';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS обавијесни извор омогућава обавештавање о новостима са овог wеб места : нове слике, обновљене категорије, нове коментаре. Користите читач RSS iзвора.';
$lang['Unknown feed identifier'] = 'Непозната ознака извора';
$lang['User comments'] = 'Кориснички коментари';
$lang['Username'] = 'Корисничко име';
$lang['Visits'] = 'Посета';
$lang['Webmaster'] = 'Мајстор за интернет странице';
$lang['Week %d'] = 'Недеља %d';
$lang['About Piwigo'] = 'О Piwigo-u';
$lang['You are not authorized to access the requested page'] = 'Нисте овлаштени за приступ затраженој страници';
$lang['add to caddie'] = 'додај у фиоку';
$lang['add this photo to your favorites'] = 'додај ову слику у омиљене';
$lang['Administration'] = 'Администрација';
$lang['all'] = 'све';
$lang['ascending'] = 'узлазно';
$lang['author(s) : %s'] = 'аутор(и) : %s';
$lang['Expand all albums'] = 'Прошири све категорије';
$lang['posted after %s (%s)'] = 'објављено после %s (%s)';
$lang['posted before %s (%s)'] = 'објављено пре %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'објављено између %s (%s) и %s (%s)';
$lang['posted on %s'] = 'објављено на %s';
$lang['Best rated'] = 'Најбоље оцењено';
$lang['display best rated photos'] = 'приказ најбоље оцењених ставки';
$lang['caddie'] = 'Фиока';
$lang['Calendar'] = 'Календар';
$lang['All'] = 'Све';
$lang['display each day with photos, month per month'] = 'приказ сваког дана са сликама, месец по месец';
$lang['View'] = 'Погледај';
$lang['chronology_monthly_calendar'] = 'Месечни календар';
$lang['chronology_monthly_list'] = 'Месечни попис';
$lang['chronology_weekly_list'] = 'Недељни попис';
$lang['Click here if your browser does not automatically forward you'] = 'Кликните овде ако нисте аутоматски пребачени';
$lang['comment date'] = 'датум коментара';
$lang['Comment'] = 'Коментар';
$lang['Your comment has been registered'] = 'Ваш је коментар уписан';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood систем : молимо сачекајте мало пре објаве новог коментара';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Ваш коментар НИЈЕ уписан јер није прошао правила овере';
$lang['An administrator must authorize your comment before it is visible.'] = 'Администратор мора одобрити ваш коментар пре објаве.';
$lang['This login is already used by another user'] = 'Ово корисничко име се већ користи';
$lang['Comments'] = 'Коментари';
$lang['Add a comment'] = 'Додај коментар';
$lang['created after %s (%s)'] = 'направљен након %s (%s)';
$lang['created before %s (%s)'] = 'направљен прије %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'направљен између %s (%s) и %s (%s)';
$lang['created on %s'] = 'направљен на %s';
$lang['Customize'] = 'Подеси';
$lang['Your Gallery Customization'] = 'Подешавање Ваше Галерије ';
$lang['day'][0] = 'Недеља';
$lang['day'][1] = 'Понедељак';
$lang['day'][2] = 'Уторак';
$lang['day'][3] = 'Среда';
$lang['day'][4] = 'Четвртак';
$lang['day'][5] = 'Петак';
$lang['day'][6] = 'Субота';
$lang['Default'] = 'Подразумевано';
$lang['delete this photo from your favorites'] = 'уклоните ову слику из омиљених';
$lang['Delete'] = 'Уклони';
$lang['descending'] = 'силазно';
$lang['download'] = 'преузми';
$lang['download this file'] = 'преузми ову слику';
$lang['edit'] = 'уреди';
$lang['wrong date'] = 'погрешан датум';
$lang['excluded'] = 'искључено';
$lang['Your favorites'] = 'Моји омиљени';
$lang['display your favorites photos'] = 'приказ мојих омиљених слика';
$lang['Favorites'] = 'Омиљени';
$lang['First'] = 'Први';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Галерија је закључана због одржавања. Молимо, навратите касније.';
$lang['Page generated in'] = 'Страница израђена у ';
$lang['guest'] = 'гост';
$lang['Hello'] = 'Поздрав';
$lang['available for administrators only'] = 'доступно само администраторима';
$lang['display this album'] = 'приказује слике у главној категорији';
$lang['display last user comments'] = 'Преглед задњих корисничких коментара';
$lang['customize the appareance of the gallery'] = 'подесите изглед ваше галерије';
$lang['search'] = 'претражи';
$lang['Home'] = 'Почетна';
$lang['in this album'] = 'у овој категорији';
$lang['in %d sub-album'] = 'у %d подкатегорији';
$lang['in %d sub-albums'] = 'у %d подкатегорија';
$lang['included'] = 'укључено';
$lang['Invalid password!'] = 'Погрешна лозинка!';
$lang['Language']='Језик';
$lang['last %d days'] = 'задњих %d дана';
$lang['Last'] = 'Задњи';
$lang['Logout'] = 'Одјава';
$lang['E-mail address'] = 'Адреса електронске поште';
$lang['obligatory'] = 'обвезно';
$lang['Maximum photo height'] = 'Највећа дозвољена висина слика';
$lang['Maximum height must be a number superior to 50'] = 'Највећа висина мора бити број већи од 50';
$lang['Maximum photo width'] = 'Највећа дозвољена ширина слика';
$lang['Maximum width must be a number superior to 50'] = 'Највећа ширина мора бити број већи од 50';
$lang['display a calendar by creation date'] = 'приказ календара по датуму израде';
$lang['display all photos in all sub-albums'] = 'приказ свих ставки у свим подкатегоријама';
$lang['return to normal view mode'] = 'повратак у уобичајени начин прегледа';
$lang['display a calendar by posted date'] = 'приказ календара по датуму објаве';
$lang['month'][10] = 'Октобар';
$lang['month'][11] = 'Новембар';
$lang['month'][12] = 'Децембар';
$lang['month'][1] = 'Јануар';
$lang['month'][2] = 'Фебруар';
$lang['month'][3] = 'Март';
$lang['month'][4] = 'Април';
$lang['month'][5] = 'Мај';
$lang['month'][6] = 'Јун';
$lang['month'][7] = 'Јул';
$lang['month'][8] = 'Август';
$lang['month'][9] = 'Септембар';
$lang['Most visited'] = 'Најпосјећеније';
$lang['display most visited photos'] = 'приказ најпосјећенијих слика';
$lang['Unknown identifier'] = 'Непозната ознака';
$lang['New password'] = 'Нова лозинка';
$lang['Rate this photo'] = 'Оцени ову слику';
$lang['Next'] = 'Следећи';
$lang['no rate'] = 'без оцене';
$lang['Photos posted within the last %d day.'] = 'Ставке објављене у задњем %d дану.';
$lang['Photos posted within the last %d days.'] = 'Ставке објављене у задњих %d дана.';
$lang['password updated'] = 'лозинка обновљена';
$lang['Recent period must be a positive integer value'] = 'Раздобље мора бити позитивна целобројна вредност';
/* DEPRECATED USED IN comments.php FOR image_id ? */ $lang['photo'] = 'слика';
$lang['Click on the photo to see it in high definition'] = 'Кликни на слику за преглед у високој резолуцији';
$lang['Show file metadata'] = 'Прикажи мета податке записа';
$lang['Powered by'] = 'Урађено у';
$lang['Preferences'] = 'Подешења';
$lang['Previous'] = 'Претходни';
$lang['Random photos'] = 'Слике по случајном избору';
$lang['display a set of random photos'] = 'приказ слика по случајном избору';
$lang['Recent albums'] = 'Недавне категорије';
$lang['display recently updated albums'] = 'приказ недавно обновљених категорија';
$lang['Recent period'] = 'Недавно раздобље';
$lang['Recent photos'] = 'Недавне слике';
$lang['display most recent photos'] = 'приказ најновијих слика';
$lang['Redirection...'] = 'Преусмеравање...';
$lang['Please, enter a login'] = 'Молимо, пријавите се';
$lang['login mustn\'t end with a space character'] = 'пријава не сме завршавати размаком';
$lang['login mustn\'t start with a space character'] = 'пријава не сме почињати размаком';
$lang['this login is already used'] = 'ово корисничко име се већ користи';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'адреса електронске поште мора бити облика xxx@yyy.eee (нпр. : korisnik@stranica.org)';
$lang['please enter your password again'] = 'молимо унесите лозинку поново';
$lang['Auto login'] = 'Упамти ме';
$lang['remove this tag from the list'] = 'уклони  ову ознаку из пописа';
$lang['representative'] = 'представник';
$lang['Search for Author'] = 'Претраживање по аутору';
$lang['Search in albums'] = 'Претраживање у категоријама';
$lang['Search by Date'] = 'Претраживање по датуму';
$lang['Date'] = 'Датум';
$lang['End-Date'] = 'Крајњи датум';
$lang['Kind of date'] = 'Врста датума';
$lang['Search for words'] = 'Претраживање по речима';
$lang['Search for all terms'] = 'Претраживање по свим критеријумима ';
$lang['Search for any terms'] = 'Претраживање по било којем критеријуму';
$lang['Empty query. No criteria has been entered.'] = 'Празна претрага. Није унешено ни једно поље.';
$lang['Search Options'] = 'Могућности претраживања';
$lang['Search results'] = 'Резултати претраживања';
$lang['Search in sub-albums'] = 'Претраживање у подкатегоријама';
$lang['searched words : %s'] = 'тражене речи : %s';
$lang['Contact'] = 'Контакт';
$lang['set as album representative'] = 'постави за представника категорије';
$lang['Show number of comments'] = 'Pрикажи број коментара';
$lang['Show number of hits'] = 'Прикажи број посета';
$lang['slideshow'] = 'клизни приказ';
$lang['stop the slideshow'] = 'заустави клизни приказ';
$lang['Specials'] = 'Посебне категорије';
$lang['SQL queries in'] = 'SQL упит у ';
$lang['display only recently posted photos'] = 'приказ само недавно објављених слика';
$lang['return to the display of all photos'] = 'повратак у приказ свих слика';
$lang['the beginning'] = 'почетак';
$lang['Interface theme'] = 'тема';
$lang['Thumbnails'] = 'Сличице';
$lang['Menu'] = 'Избор';
$lang['A comment on your site'] = 'Коментар на Вашој интернет страници';
$lang['today'] = 'данас';
$lang['Update your rating'] = 'Обновите своју оцену';
$lang['wrong filename'] = 'погрешан назив датотеке';
$lang['the username must be given'] = 'мора се уписати корисничко име';
$lang['useful when password forgotten'] = 'корисно када се заборави лозинка';
$lang['Quick search'] = 'Брзо претраживање';
$lang['Connected user: %s'] = 'Повезани корисник: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Претраживач: %s';
$lang['Author: %s'] = 'Аутор: %s';
$lang['Comment: %s'] = 'Коментар: %s';
$lang['Comment by %s'] = 'Коментарисао-ла %s';
$lang['User: %s'] = 'Корисник: %s';
$lang['Email: %s'] = 'Електронска адреса: %s';
$lang['Admin: %s'] = 'Администратор: %s';
$lang['Registration of %s'] = 'Пријава од %s';
$lang['Album: %s'] = 'Категорија: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Лош статус за корисника "гост", користи се подразумевани статус. Молимо обавестите мајстора интернет страница.';
$lang['this email address is already in use'] = 'корисник већ користи ову адресу електронске поште';
$lang['Album results for'] = 'Резултати категорије за ';
$lang['Tag results for'] = 'Резултати ознака за';
$lang['from %s to %s'] = 'од %s до %s';
$lang['Play of slideshow'] = 'Покрени клизни приказ';
$lang['Pause of slideshow'] = 'Заустави клизни приказ';
$lang['Repeat the slideshow'] = 'Понови клизни приказ';
$lang['Not repeat the slideshow'] = 'Не понављај клизни приказ';
$lang['Reduce diaporama speed'] = 'Смањи брзину ';
$lang['Accelerate diaporama speed'] = 'Повећај брзину ';
$lang['Submit'] = 'Пошаљи';
$lang['Yes'] = 'Да';
$lang['No'] = 'Не';
$lang['%d photo']='слика %d';
$lang['%d photos']='%d слике';
$lang['%d photo is also linked to current tags'] = '%d слика такође повезана са тренутним ознакама';
$lang['%d photos are also linked to current tags'] = '%d слике такође повезана са тренутним ознакама';
$lang['display photos linked to this tag'] = 'Прегледај слике повезане само са овом ознаком';
$lang['photos posted during the last %d days'] = 'слике објављене током задњих %d дана';
$lang['Piwigo Help'] = 'Piwigo Помоћ';
$lang['Rank'] = 'Редослед';
$lang['group by letters'] = 'сложено по словима';
$lang['letters'] = 'слова';
$lang['show tag cloud'] = 'прикажи означен облак';
$lang['cloud'] = 'облак';
$lang['Reset to default values'] = 'Врати на подразумеване вредности';
$lang['delete all photos from your favorites'] = 'обриши све слике из Омиљени';
$lang['Sent by'] = 'Послао';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Cookies су блокирани или нису подржани од Вашег претраживача. Морате омогућити цоокиес да би се логовали.';
$lang['edit this comment'] = 'уреди овај коментар';
$lang['Edit a comment'] = 'Уреди коментар';
$lang['Are you sure?'] = 'Јесте ли сигурни?';
$lang['(!) This comment requires validation'] = '(!) Овај коментар захтева оверу';
$lang['Welcome'] = 'Добродошли';
$lang['Welcome to your Piwigo photo gallery!'] = 'Добродошли у Вашу Piwigo фото галерију!';
$lang['... or browse your empty gallery'] = '... или претражи Вашу празну галерију';
$lang['... or please deactivate this message, I will find my way by myself'] = '... или искључите ову поруку, урадићу то на свој начин';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Здраво %s, Ваша Piwigo фото галерија је празна!';
$lang['I want to add photos'] = 'Желим да додам фотографије';
$lang['Manage this user comment: %s'] = 'Уреди коментаре овог корисника: %s';
$lang['This author modified following comment:'] = 'Овај аутор је мењао текући коментар:';
$lang['This author removed the comment with id %d'] = 'Овај аутор је уклонио коментар са идентификацијом %d';
$lang['delete this comment'] = 'обриши овај коментар';
$lang['validate this comment'] = 'овери овај коментар';
$lang['html tags are not allowed in login'] = 'html ознаке нису дозвољене овде';
$lang['The number of photos per page must be a not null scalar'] = 'Број фотографија по страни мора бити већи од нуле';
$lang['Number of photos per page'] = 'Број фотографија по страници';
$lang['%d rates'] = '%d оцена';
$lang['Rating score'] = 'Оцена резултата';
$lang['Enter a username or email address'] = 'Унеси корисничко име или е-адресу';
$lang['Invalid username or email'] = 'Неправилно корисничко име или адреса е-поште';
$lang['Password reset is not allowed for this user'] = 'Поништавање лозинке није дозвољено за овог корисника';
$lang['User "%s" has no email address, password reset is not possible'] = 'Корисник "%s" нема адресу е-поште, поништавање лозинке није могуће';
$lang['Someone requested that the password be reset for the following user account:'] = 'Неко је захтевао да се лозинка поништи за корисничко налог:';
$lang['Username "%s" on gallery %s'] = 'Корисничко име "%s" у галерији %s';
$lang['To reset your password, visit the following address:'] = 'Да бисте поништили Вашу лозинку прочитајте пошту са следеће е-адресе:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Ако је ово грешка, занемарите ову поруку и ништа се неће десити.';
$lang['Password Reset'] = 'Поништавање лозинке';
$lang['Check your email for the confirmation link'] = 'Проверите вашу е-пошту за везу за потврду';
$lang['Invalid key'] = 'Лош кључ';
$lang['The passwords do not match'] = 'Лозинке нису једнаке';
$lang['Your password has been reset'] = 'Ваша лозинка је поништена';
$lang['Return to home page'] = 'Повратак на почетну страницу';
$lang['Please enter your username or email address.'] = 'Молимо Вас да унесете корисничко име или е-адресу.';
$lang['You will receive a link to create a new password via email.'] = 'Добићете везу  преко е-поште да бисте променили лозинку.';
$lang['Username or email'] = 'Корисничко име или е-адреса';
$lang['Change my password'] = 'Промени моју лозинку';
$lang['Enter your new password below.'] = 'Унесите Вашу нову лозинку испод.';
$lang['Reset Password'] = 'Поништи лозинку';


?>